@@ -15,7 +15,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA.
 
     Permission is also granted to link this program with the Qt
     library, treating Qt like a library that normally accompanies the
@@ -26,9 +27,9 @@
 #ifndef KCMAUDIOCD_H
 #define KCMAUDIOCD_H
 
-#include <QList>
 #include <KCModule>
 #include <KConfig>
+#include <QList>
 
 class KConfigDialogManager;
 
@@ -37,22 +38,22 @@ class KConfigDialogManager;
 class AudiocdConfig : public QWidget, public Ui::AudiocdConfig
 {
 public:
-  explicit AudiocdConfig( QWidget *parent ) : QWidget( parent ) {
-    setupUi( this );
-  }
+    explicit AudiocdConfig(QWidget *parent)
+        : QWidget(parent)
+    {
+        setupUi(this);
+    }
 };
 
-
 class KAudiocdModule : public KCModule
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
+    explicit KAudiocdModule(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+    ~KAudiocdModule();
 
-  explicit KAudiocdModule(QWidget *parent=nullptr, const QVariantList &args=QVariantList());
-  ~KAudiocdModule();
-
-  QString quickHelp() const override;
+    QString quickHelp() const override;
 
 public Q_SLOTS:
   void defaults() override;
@@ -67,7 +68,7 @@ private Q_SLOTS:
 
 private:
   KConfig *config;
-  bool configChanged;
+  bool configChanged = false;
 
   int getBitrateIndex(int value);
 
